@@ -1,4 +1,4 @@
-/* $Id: mutt_socket.h,v 1.4 1998/10/13 20:45:39 roessler Exp $ */
+/* $Id: mutt_socket.h,v 1.5 1998/10/20 09:31:15 roessler Exp $ */
 /*
  * Copyright (C) 1998 Brandon Long <blong@fiction.net>
  * 
@@ -20,7 +20,7 @@
 #ifndef _MUTT_SOCKET_H_
 #define _MUTT_SOCKET_H_ 1
 
-typedef struct
+typedef struct _connection
 {
   char *server;
   int port;
@@ -30,6 +30,7 @@ typedef struct
   int bufpos;
   int available;
   void *data;
+  struct _connection *next;
 } CONNECTION;
 
 int mutt_socket_readchar (CONNECTION *conn, char *c);
