@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: mx.c,v 1.18 1998/11/10 21:02:25 roessler Exp $";
+static const char rcsid[]="$Id: mx.c,v 1.19 1998/11/10 22:14:36 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -56,7 +56,7 @@ static const char rcsid[]="$Id: mx.c,v 1.18 1998/11/10 21:02:25 roessler Exp $";
 #endif
 
 
-#define mutt_is_spool(s)  (strcmp (NONULL(Spoolfile), s) == 0)
+#define mutt_is_spool(s)  (mutt_strcmp (Spoolfile, s) == 0)
 
 #ifdef USE_DOTLOCK
 /* parameters: 
@@ -353,9 +353,9 @@ int mx_get_magic (const char *path)
 #endif
 
     fgets (tmp, sizeof (tmp), f);
-    if (strncmp ("From ", tmp, 5) == 0)
+    if (mutt_strncmp ("From ", tmp, 5) == 0)
       magic = M_MBOX;
-    else if (strcmp (MMDF_SEP, tmp) == 0)
+    else if (mutt_strcmp (MMDF_SEP, tmp) == 0)
       magic = M_MMDF;
     fclose (f);
 #ifndef BUFFY_SIZE
@@ -384,15 +384,15 @@ int mx_get_magic (const char *path)
  */
 int mx_set_magic (const char *s)
 {
-  if (strcasecmp (s, "mbox") == 0)
+  if (mutt_strcasecmp (s, "mbox") == 0)
     DefaultMagic = M_MBOX;
-  else if (strcasecmp (s, "mmdf") == 0)
+  else if (mutt_strcasecmp (s, "mmdf") == 0)
     DefaultMagic = M_MMDF;
-  else if (strcasecmp (s, "mh") == 0)
+  else if (mutt_strcasecmp (s, "mh") == 0)
     DefaultMagic = M_MH;
-  else if (strcasecmp (s, "maildir") == 0)
+  else if (mutt_strcasecmp (s, "maildir") == 0)
     DefaultMagic = M_MAILDIR;
-  else if (strcasecmp (s, "kendra") == 0)
+  else if (mutt_strcasecmp (s, "kendra") == 0)
     DefaultMagic = M_KENDRA;
   else
     return (-1);
