@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: rfc2047.c,v 1.8 1998/11/10 22:14:52 roessler Exp $";
+static const char rcsid[]="$Id: rfc2047.c,v 1.10 1998/12/02 10:11:58 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -69,7 +69,7 @@ static void q_encode_string (char *d, size_t dlen, const unsigned char *s)
       wordlen++;
       dlen--;
     }
-    else if ((*s & 0x80) || *s == '\t' || strchr (MimeSpecials, *s))
+    else if ((*s & 0x80) || *s == '\t' || *s == '_' || strchr (MimeSpecials, *s))
     {
       if (wordlen >= 70)
       {
@@ -236,6 +236,14 @@ void rfc2047_encode_adrlist (ADDRESS *addr)
       safe_free ((void **) &ptr->personal);
       ptr->personal = safe_strdup (buffer);
     }
+#ifdef EXACT_ADDRESS
+    if (ptr->val)
+    {
+      rfc2047_encode_string (buffer, sizeof (buffer), (const unsigned char *)ptr->val);
+      safe_free ((void **) &ptr->val);
+      ptr->val = safe_strdup (buffer);
+    }
+#endif
     ptr = ptr->next;
   }
 }
@@ -401,6 +409,10 @@ void rfc2047_decode_adrlist (ADDRESS *a)
   {
     if (a->personal && strstr (a->personal, "=?") != NULL)
       rfc2047_decode (a->personal, a->personal, mutt_strlen (a->personal) + 1);
+#ifdef EXACT_ADDRESS
+    if (a->val && strstr (a->val, "=?") != NULL)
+      rfc2047_decode (a->val, a->val, mutt_strlen (a->val) + 1);
+#endif
     a = a->next;
   }
 }
