@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: send.c,v 1.24 1998/11/10 22:21:01 roessler Exp $";
+static const char rcsid[]="$Id: send.c,v 1.27 1998/11/23 10:13:35 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -398,14 +398,14 @@ static int default_to (ADDRESS **to, ENVELOPE *env, int group)
     return 0;
   }
 
-  if (!option(OPTMETOO) && mutt_addr_is_user (env->from))
+  if (!option(OPTREPLYSELF) && mutt_addr_is_user (env->from))
   {
     /* mail is from the user, assume replying to recipients */
     rfc822_append (to, env->to);
   }
   else if (env->reply_to)
   {
-    if (mutt_addrcmp (env->from, env->reply_to) || 
+    if ((mutt_addrcmp (env->from, env->reply_to) && !env->reply_to->next) || 
 	(option (OPTIGNORELISTREPLYTO) &&
 	mutt_is_mail_list (env->reply_to) &&
 	(mutt_addrsrc (env->reply_to, env->to) ||
@@ -421,7 +421,8 @@ static int default_to (ADDRESS **to, ENVELOPE *env, int group)
        */
       rfc822_append (to, env->from);
     }
-    else if (!mutt_addrcmp (env->from, env->reply_to) &&
+    else if (!(mutt_addrcmp (env->from, env->reply_to) && 
+	       !env->reply_to->next) &&
 	     quadoption (OPT_REPLYTO) != M_YES)
     {
       /* There are quite a few mailing lists which set the Reply-To:
@@ -429,7 +430,9 @@ static int default_to (ADDRESS **to, ENVELOPE *env, int group)
        * to send a message to only the sender of the message.  This
        * provides a way to do that.
        */
-      snprintf (prompt, sizeof (prompt), _("Reply to %s?"), env->reply_to->mailbox);
+      snprintf (prompt, sizeof (prompt), _("Reply to %s%s?"),
+		env->reply_to->mailbox, 
+		env->reply_to->next?",...":"");
       if ((i = query_quadoption (OPT_REPLYTO, prompt)) == M_YES)
 	rfc822_append (to, env->reply_to);
       else if (i == M_NO)
@@ -721,7 +724,7 @@ void mutt_set_followup_to (ENVELOPE *e)
      it hasn't already been set */
   if (option (OPTFOLLOWUPTO) && !e->mail_followup_to)
   {
-    if (mutt_is_list_recipient (e->to) || mutt_is_list_recipient (e->cc))
+    if (mutt_is_list_recipient (0, e->to, e->cc))
     {
       /* i am a list recipient, so set the Mail-Followup-To: field so that
        * i don't end up getting multiple copies of responses to my mail
