@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: sendlib.c,v 1.33 1998/11/18 22:57:03 roessler Exp $";
+static const char rcsid[]="$Id: sendlib.c,v 1.34 1998/11/19 17:14:02 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -850,7 +850,7 @@ static void transform_to_7bit (BODY *a, FILE *fpin)
 
       transform_to_7bit (a->parts, fpin);
     } 
-    else if (a->type == TYPEMESSAGE && mutt_strcasecmp (a->subtype, "delivery-status"))
+    else if (mutt_is_message_type(a->type, a->subtype))
     {
       mutt_message_to_7bit (a, fpin);
     }
